@@ -1,9 +1,11 @@
 import logging
 import os
 from io import StringIO
+from typing import List, Tuple
 
 from dotenv import load_dotenv
 
+from fractal import FractalException
 from fractal.core.repositories import Repository
 from fractal.core.services import Service
 from fractal.core.utils.loggers import init_logging
@@ -25,6 +27,7 @@ class ApplicationContext(object):
         init_logging(os.getenv("LOG_LEVEL", "INFO"))
         self.logger = logging.getLogger("app")
         self.repositories = []
+        self.services = []
 
         self.load_internal_services()
         self.load_repositories()
@@ -32,6 +35,11 @@ class ApplicationContext(object):
         self.load_egress_services()
         self.load_command_bus()
 
+        for repository in self.repositories:
+            repository.is_healthy()
+        for service_name in self.services:
+            getattr(self, service_name).is_healthy()
+
     def reload(self, defaults: dict):
         self.logger.debug(f"Reloading ApplicationContext with '{defaults}'")
         filelike = StringIO("\n".join([f"{k}={v}" for k, v, in defaults.items()]))
@@ -76,6 +84,15 @@ class ApplicationContext(object):
     def install_service(self, service, *, name=""):
         if not name:
             name = camel_to_snake(service.__name__)
+        self.services.append(name)
         setattr(
             ApplicationContext, name, property(lambda self: next(service.install(self)))
         )
+
+    def get_parameters(self, parameters: List[str]) -> Tuple:
+        for parameter in parameters:
+            if not hasattr(self, parameter):
+                raise FractalException(
+                    f"ApplicationContext does not provide '{parameter}'"
+                )
+        return tuple(getattr(self, p) for p in parameters)
